@@ -3,6 +3,7 @@
 from evalcache.dircache import DirCache
 from evalcache.lazy import Lazy, LazyObject, LazyHash, Memoize
 from evalcache.lazy import unlazy, encache, decache, nocache, print_tree
+from evalcache.lazy import unlazy_if_need
 from evalcache.lazyfile import LazyFile
 
-from evalcache.util import select
+from evalcache.util import select, map, filter, reduce
